==> mule-metadata-model-api-1.2.0-20210120-sources.jar: org/mule/metadata/api/model/impl/DefaultAttributeKeyType.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.metadata.api.model.impl;

import org.mule.metadata.api.annotation.TypeAnnotation;
import org.mule.metadata.api.model.AttributeKeyType;
import org.mule.metadata.api.model.MetadataFormat;
import org.mule.metadata.api.visitor.MetadataTypeVisitor;

import javax.xml.namespace.QName;
import java.util.Map;
import java.util.Optional;
import java.util.regex.Pattern;

public class DefaultAttributeKeyType extends BaseMetadataType implements AttributeKeyType {

  private Optional<QName> name;
  private Optional<Pattern> pattern;

  public DefaultAttributeKeyType(Optional<QName> name, Optional<Pattern> pattern, MetadataFormat metadataFormat,
                                 Map<Class<? extends TypeAnnotation>, TypeAnnotation> extensions) {
    super(metadataFormat, extensions);
    this.name = name;
    this.pattern = pattern;
  }

  @Override
  public QName getName() {
    return name.get();
  }

  @Override
  public Pattern getPattern() {
    return pattern.get();
  }

  @Override
  public boolean isName() {
    return name.isPresent();
  }

  @Override
  public boolean isPattern() {
    return pattern.isPresent();
  }

  @Override
  public void accept(MetadataTypeVisitor visitor) {
    visitor.visitAttributeKey(this);
  }
}

==> mule-metadata-model-api-1.3.0-20210823-sources.jar: org/mule/metadata/api/model/impl/DefaultAttributeKeyType.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.metadata.api.model.impl;

import org.mule.metadata.api.annotation.TypeAnnotation;
import org.mule.metadata.api.model.AttributeKeyType;
import org.mule.metadata.api.model.MetadataFormat;
import org.mule.metadata.api.visitor.MetadataTypeVisitor;

import java.util.Map;
import java.util.Optional;
import java.util.regex.Pattern;

import javax.xml.namespace.QName;

public class DefaultAttributeKeyType extends BaseMetadataType implements AttributeKeyType {

  private final Optional<QName> name;
  private final Optional<Pattern> pattern;

  public DefaultAttributeKeyType(Optional<QName> name, Optional<Pattern> pattern, MetadataFormat metadataFormat,
                                 Map<Class<? extends TypeAnnotation>, TypeAnnotation> extensions) {
    super(metadataFormat, extensions);
    this.name = name;
    this.pattern = pattern;
  }

  @Override
  public QName getName() {
    return name.get();
  }

  @Override
  public Pattern getPattern() {
    return pattern.get();
  }

  @Override
  public boolean isName() {
    return name.isPresent();
  }

  @Override
  public boolean isPattern() {
    return pattern.isPresent();
  }

  @Override
  public void accept(MetadataTypeVisitor visitor) {
    visitor.visitAttributeKey(this);
  }
}
